
# q-expansion of newform 350.10.a.v, downloaded from the LMFDB on 20 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 350
weight = 10
poly_data = [152654544, 142780860, 22509888, 704364, -19610, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0], 1], [[-2491279011995760, -637617943193730, -22908245479098, 595084857083, 118583794, -30253357], 7048620009396], [[32899676268247740, -1813076837738562, -476612542972146, 8295933771943, 9861530420, -424746695], 7048620009396], [[-7757083317064284, -2571369002215620, -85321813931718, 2235931504958, 396214819, -113590357], 1762155002349], [[8139203332195824, 2490150966112650, 139011545028720, -3172527158575, -1431567095, 162608450], 2349540003132], [[2192591183200236, 3409557054388980, 222955837312236, -4887969075476, -2562909013, 251124229], 1762155002349]]

hecke_ring_character_values = None
aps_data = [[16, 0, 0, 0, 0, 0], [-13, -1, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0], [-2401, 0, 0, 0, 0, 0], [2574, 77, -1, 4, -19, -11], [-5328, -18, -15, -20, -12, 9], [6894, 1053, -23, 36, 71, -8], [-75592, -337, -64, -35, 181, 81], [-213480, 2680, 286, 186, -278, -119], [499685, 10108, 168, 255, 699, 883], [-1746036, 8160, -1046, -339, 92, -1122], [3833230, -32472, 328, -1336, 1144, 775], [-6791754, 42778, -2408, -2805, -3970, 2096], [-4682504, 18214, -720, 2311, -3982, -4276], [2157821, -23546, -926, -2990, -2541, -6631], [8826910, 155922, 8992, 5649, -9510, 14353], [272804, 98343, 8314, 17964, 33957, -18143], [-37226588, 103461, 7736, -16861, -13527, 27379], [2505502, 884228, 13736, 12594, 48370, 2222], [-44408918, -465028, 50550, 13595, 40284, -42355], [-6413210, 1543862, 32568, 23999, 43882, 10261], [-121516378, -1065453, 36241, 18535, -118507, 47078], [-168780632, 1658533, -58024, -97834, -111377, 20455], [-248537344, -1543744, -27008, 21021, 76454, -6770], [-360505650, 301513, -22567, 89184, 100575, 81230], [-51832596, 863993, -325516, 633, -63755, -91587], [23484993, -187566, 68182, -102702, 482247, 53431], [-464664344, 321040, -198344, 25262, 490928, 111260], [66067411, -4234384, 152336, -217055, -438963, 81071], [150303730, 3603020, 173064, -21174, -200040, -155593], [-778229828, 8344092, 244906, 309191, -1120562, 72449], [669180292, -13261159, 473362, -828881, -540401, 767019], [-1215353376, -18017024, -415944, -422463, 452948, -1106796], [-1566569692, 9224801, 323398, 724430, 486403, -209841], [492123362, -23392132, 173648, 34200, 2316416, 963016], [-1981936968, 2376059, -633585, -1033500, -2646823, -306857], [-3982823506, -3623093, -203876, 219393, 3440265, 755824], [-229121870, -30404314, 1106444, 373588, 1164520, 1674138], [-5118306579, 2711274, -987030, 1092684, -3625509, -2447113], [-3712589104, -71291194, 1622527, 238834, 187064, 1209719], [-673694956, -20090284, 935416, 2567014, 4388116, -1140158], [-6031386338, -50746451, 631476, 1781758, -3749949, -986151], [-5486880690, -47674423, 946899, -102789, 3310891, 3741574], [1803346182, -82596546, -721354, 2344332, -1305138, 2177171], [-3923265878, -23937018, 2714924, -2574992, 1006458, 4260199], [-13196731676, -50715092, 2182658, -1872554, 2112636, -1086286], [-22056425266, -72521683, 522621, 4333358, 2500625, 2422503], [17016177677, 51227144, -3256142, -1807562, -8714927, -7587133], [-11134869801, -13253737, -7821228, 1413096, -10088164, 3316964], [-26849454362, -32788953, 8345192, -31715, 6717921, 2141555], [11647629484, 149947840, 2936948, -5461342, 10343288, 2602050], [-33870603260, 84132631, 3809023, -9978190, -5227583, 10333419], [2796089326, -82655170, 2404260, 4417383, -10575962, 9427714], [-12406799508, -116527215, -11135562, -3670954, 18140883, -12657001], [11799396910, -123405378, -5629896, -3765687, 19674026, 8344589], [-2125789992, 109226524, -16750064, -526204, -757412, -10642824], [-51709531478, -67340831, -4299636, -3411222, -11542085, -22733907], [-48515637108, 364311340, 314728, 6008399, 2846416, -10111910], [31304627986, 180787522, -9651072, -23471511, -47177014, 4029003], [-35074233769, -337215624, 2232534, 2258541, 9880381, 26963665], [37879225381, -134722213, 9171476, 16204698, -8075474, -6123114], [-8010698012, 776794924, 5629091, 4588456, 3720918, 3337645], [111849473473, -144753237, -15531700, 1382594, 59541634, -16501586], [-44755784652, -9009856, 11458140, 22605737, -9862628, -26901046], [16058632334, -479807341, -10749593, -24397498, -30709283, 14536172], [19676710954, 241501812, 7105682, 17259099, 34744316, 2908519], [-30893182636, 213378394, -33167192, -53121360, 26788838, 1463236], [62322704374, -105268044, 8688272, -55554997, -82438132, 9445257], [28485418914, -1360308174, 25418092, 16344219, 49944124, 55267840], [-99028350220, 9441617, 17385628, 39544803, -28163255, -2988571], [11456228426, -1447620657, -12634711, 17865122, -85294591, -79770838], [-151957432032, 437216796, -6517276, -25626068, -127907572, 72819658], [-149757157771, -557896944, 25806106, -1444780, 31449813, 23054001], [126303303658, 1393926236, -23896886, 9321052, -18067640, 7587167], [-71081246808, 414197650, -26667332, -3548614, 22584206, -114407722], [-15017113164, -1467920254, 21859724, -86250308, 17205014, -39408060], [-138117077285, 2310903996, -29723952, -125845309, -87939311, -14317577], [-185417550372, -335903118, -53490093, 30699080, -169134752, -33026785], [-7163419545, 1145830710, 38371712, 111338746, 71538321, -7417260], [119387731444, 1253693318, 35092596, -35339754, 145398452, 20067756], [-164159069292, -1037531109, -16116018, 27108784, 6962369, 53370297], [-188820246437, 259126806, 32050472, 57714867, -68832049, 185749459], [24294125472, 2892563533, -82130707, 77716394, -45425001, -133492659], [112374140158, 1236397860, -9432564, 64028471, -208302444, 5773403], [161464581192, -2657819662, 126321166, 91165524, 189571142, 155228542], [-102995587260, 1034872828, 25985612, 27495841, -33225428, -117278388], [717136905819, -288025424, 13225262, -160171509, 36892489, -71748661], [31587945218, -450852604, -70982060, -86033248, 27405016, -174723657], [158319082216, -4759767351, -94543284, -34728410, -20816167, -19391897], [454627936188, 131864296, 74277460, 48464579, -220533384, 157390508], [-5847518531, 2719862221, 31498788, 216970182, 250335364, 4387368], [240076129016, -2748077612, -85325370, -58828731, -546143560, -196406092], [820389689272, 214116536, 58949798, 45757641, 159451922, -115451937], [615606606262, -4693504743, 97902129, 156842220, -255165607, -38281623], [703205249182, -4232976869, -153393073, 248752146, 79997679, -48941781], [759398605343, 3693080720, -58047730, -253761752, -121394621, 160981453], [1238159026674, 129736199, -32634828, -317142128, -17072303, 136830911], [277656217876, -12827799262, 129700208, 264124491, -117187428, -119004488], [608031181192, 6140655531, 283260560, 121023738, -41427279, 55706793], [46378298537, 502271314, -169489844, -455870133, -224351971, 252365193], [1047825212276, -7730158558, 195065248, 162126319, -576042422, -216694840], [810722096814, -2237186192, -134295810, 42190895, -773208736, -17920587], [171421061020, -369933323, -223706128, -356359400, 377790275, -618278809], [1170919837620, 12995744070, -378265978, -18836473, -86739902, 24103109], [445040203800, 9041206982, 391051020, -34397444, -90122638, -189600294], [-228804190686, 816688957, 274159187, 270342814, -138622729, 482669170], [565319621600, -6801489739, -666270568, -21827312, -223321025, 136336671], [906234941050, -3311425671, -283503593, -388642008, -176882913, -2872208], [581636571814, 1630107721, 766369287, 229570003, -349632509, 240732838], [-1318341196272, -13064795460, 549207852, 315138228, 245164862, 35267774], [-4882947409, -714665296, -215089294, 215137596, 499039467, -531843551], [141979431838, -10524957610, -83618218, -91228545, -1116623934, -487160157], [1797325461058, -11320383432, 89443492, 441609875, 1194530584, 111175643], [-1327134305844, -18562190457, -377728130, -168424871, -613423935, -119587579], [-98930835682, -7231943695, -472093293, -225316655, -1788061157, -686761954], [513811465652, 40952646274, 408905818, 362424829, 1336794342, 85585779], [899196349967, -27404000181, -878987852, -89015186, -420543712, -12481508], [691872239860, -22839639486, -430892876, 35976540, -149869242, 25692316], [1189335441298, -28550227998, -54193866, 22344166, -90971550, 759001417], [602293312390, -22847098043, -526515045, 189520040, 75179369, 478890007], [62145574868, -17287943853, -455499688, -318369662, 717623003, 415756767], [146009788704, -18702380052, -9496972, -138266035, 1086275672, 1002518328], [321380886204, 2401090652, 310492681, -317995948, -1397782218, 749413837], [363521732136, 12791210232, -512570276, 473812815, 872461388, -183407428], [71196794128, 25217423199, 668204276, 200847432, -1115018911, 1609573273], [-358622775347, -15356566588, 614072, -1130113485, 587387635, -1458415369], [2944523325533, 22091869044, 886223808, 775135065, 2396814415, -837890347], [-1818066029444, 4402810544, -2150468074, -1346711535, 1435877596, -147263406], [-3921400576852, 15034767818, 101870080, -1371691530, -1295266950, 19774322], [283795764272, 11127640614, -543129319, 112121710, 2656807280, -303582425], [-4935174014418, 31179228497, 167639375, -983365252, -1778852843, 802155499], [-5040073308432, 1938010308, -204955186, -1067163717, -439329778, 1382011215], [-839767083320, 25259844395, 884950043, 953341008, 507820729, 946732639], [-1229023191042, -39960398958, -655806214, -273446891, 1308967638, 1323359915], [740062708974, 35627541602, 312107304, 958447371, 2368336930, 1312760888], [-7667745149600, 6733434302, -144882116, -1010018264, 652938628, -78098992], [-1816755484736, 7237203988, -929475083, -2625817418, -5180224330, 247683207], [-1876433604901, 14034111541, 315411680, 230604248, -1547037174, 1582384386], [-488528100880, -11586461436, 1165373187, 649438782, 3392437958, -1517725277], [-8841128554993, 68635929722, 1762145696, -301553262, 887817481, 520476288], [-10268749673380, -45358731799, 985234874, 1134310980, -2077284901, 1178514443], [392189480819, 36710570066, 2013868916, 531686709, -1903595485, -1593109673], [5416029156826, -13596101992, -1709346576, -113737195, 4820612094, -2242413294], [-3871361065666, -59270490400, 254658684, 845052040, -1113887838, -2791145636], [-10154774546866, 41814589357, -2349023084, -1639758165, 875341459, 229280419], [-12134680386984, -55629579680, 2336750018, 2014440745, 2814899492, -1797739188], [2174412980822, 36472941059, 1207739096, 2124264951, -2777422311, 624584616], [8630628644458, -28747013644, 517622816, 1937745165, 1590040052, -898212803], [-2046165415560, -56009120079, -144983428, -2077510762, 2106478735, -2701314241], [-7024187394670, 20032033436, -2137916296, -206246423, 2802431410, 3046893046], [7518916158398, 23899530130, -3678288594, 171772576, -1811994982, -3154228121], [-11022047851268, 34064692064, -470891296, 308185352, -4791986518, -5113604140], [-574098309820, -36839370756, 2543580060, 1090373023, -4515894044, -2686790596], [-7165726884328, 17742877158, -3787880332, -1272336276, 308364534, -705027836], [2825085027038, -53293260344, 482094372, -106978287, 1091185050, 289873610], [-855040716504, 5510673300, 932614796, -1556671864, -6577321708, -355857966], [3710566822758, -77150737553, -545873919, 2185057967, 2656350401, -3318251930], [8111850712330, 29401411042, -1881064860, -274788362, -8123221310, 1611392756], [7043309673030, 22147829651, 5086083829, 980287196, 5669294881, 3727806690], [2275510768004, 39710776107, -754802848, -3614981717, -6253564729, -2636439707], [7818845240214, 9210014922, -3074042172, -3553438047, -734491560, -3249539856], [-22381131265164, -51888184722, -1235849418, 589795787, -12993125650, 572128096], [-17466092891382, -119059615232, -1177836034, -976776445, -1060530336, 1369867551], [5211893251820, 54697299603, -1902550806, -200747103, -631637147, -118872723], [-5928993289608, -87027525248, -558608816, -1761784703, 1889558436, -3791447792], [-10284002450433, -117158830770, 1685848106, 766891714, 11467056061, 3549147547], [-6249475238370, -2627319896, 2875014346, 5342088607, 3492933832, -3748394029], [14764823706872, -129028726102, -3572603405, -373869378, -174005016, 3382483841], [15149584405635, 138913696298, -1559409160, -6032977272, 1172034893, 168289892], [-37660275710646, -14785637339, 582621280, 1674123699, -943326705, -2733305736], [6879771783988, -165342179020, 951091704, -1487097652, -1136529876, -3389756566], [3705477004716, 45493576987, -4707209680, -2241724208, 986483191, 3726534375], [-1692690624078, -17349167015, -3688042793, -4337435099, 329703227, 3924054516], [20660887136444, -123108247222, 1935789502, -3252396376, -2890864234, 5850569164], [726220787100, 152014414274, -2286667916, -6472825249, -4266565398, 4678027464], [-17202318642720, -27367723400, -1857968324, -1814946974, 5466098106, 1370745234], [3902135632734, -63158100173, -4057660685, 8143012390, -3708625321, -4988520957], [-12880368510357, -180617076460, -7819709720, -2664820341, -19786404811, -3670074403], [-6332314736688, 34039742592, 5143926036, -1870340492, -2755060052, -2649464238], [24483769703456, 96778897339, 2363415648, 7839831649, -5014118365, 1638069453], [17348834458758, 120500195704, 12148312326, 3491706120, 9859205052, 4167758653], [15283251771096, 168605694429, 1772344904, 1352852589, 4783577151, -5485482249], [-98961134478, 98066517474, -5090163902, 3172001568, 17185602210, -4968223579], [5042512516566, 9304860838, 7413887132, -2393645837, -12956756198, 1215752037], [-12762914828774, 62344064156, 6370609046, 9665917286, -902832500, -1041643359], [6756711487938, 73433689553, -3340398188, 141653909, -20438406601, -6096277693], [-9604873936462, -110152032778, -8179773676, -2642602083, -450751210, -5158382641], [6675484552907, -14372777489, -4865356708, 5113365970, -4813796408, -13525420644], [52005585439349, -99108794760, -30458794, -1188244217, -5866306645, -835266631], [4787488479872, -59007413390, 11222196376, -3248355523, -2832928822, 8427754446], [-46900418636230, 73960538318, -6183925284, 4509049249, 7847129042, -11255382465], [-52730278179776, -58208618376, 5068584128, 4408324729, 11674390520, 8721403634], [-1126114723710, -280077114279, -2309183523, -4710826398, 1260721609, -3391715093], [5839940672270, -5465910295, 1326917988, -7804940329, 22749804419, 12419151331], [-24632981422672, -32499385952, 7640670028, 4390519340, 11994019852, -8854110686], [-2954647037514, 115758641465, 143168999, 11330441182, 1876992291, 2188420684], [-37786991642931, -212020885822, -4696951276, 5839770984, -15102323769, 11594340090], [23278054111446, -294545468648, 20785254516, 8730498322, -13496586136, 10250551], [-13479853502530, 33102329495, -3569674699, -7213136400, 24218661325, 18217568722], [-84832025186679, -30313627524, 9398734938, -4328166636, 7408410677, 7894941061], [21825347975946, -94374348184, -9524730764, -9601948488, 27534519332, 10211631946], [-19431062362608, 490980851082, 9416707556, -4574697898, -13634172178, 378535610], [-8418198554782, 125782759815, 3277642268, -10556148603, 23082928773, 10568820686], [23391817596776, -1774912116, -13917558052, -2380344737, -2003162426, -27198518156], [-12418062977696, 471423894295, 6760847860, 5913455325, -17166268787, 9130166317], [-8054099752884, 47785340648, -11758369653, -4926153906, -16094978918, -1895161519], [27160732034588, 229122641384, 8053195162, 7342910942, 12454267776, 9144483274], [-11885922924492, -317849932770, -13171074304, -24214829211, 4010030862, -4019700224], [46142197583024, 88703036110, 18064734650, 1064727485, -14666096394, -5855023369], [37554766966000, 422881159735, -11913701316, -20636530377, -6950126803, 19385117381], [10968992805946, 181554358912, 2644854984, 2874708208, -14071121820, 9061881471], [12832985973674, 95187572803, -2280892296, 11556335534, 29871775953, -17018140739], [-19979517219528, -310897885348, -16624601182, -13833797450, -7134044254, -5860778149], [-25525657064021, 228567840043, 1603965016, 16362101356, 23698814780, 8357715548], [-51528598882344, 531146410136, -1226904228, 10554195544, 32921392304, 3870216580], [-75319939803048, -65302685142, -6896910548, 6212690867, -16930975624, -15960233594], [28780658397594, 3657188192, -2183698448, 4237031569, -26522760002, 18178044894], [39491936047954, 208081830790, -5454680964, -12836296021, -35024242738, 18740700090], [-8359848831900, -2506288848, -8471018700, 11029498187, -32398297912, 21814836540], [-58945698636202, -169346676328, 12577937692, 13992662825, -15480128492, -21398018585], [-12582081297122, -247840842378, 31839592936, 15574888820, -18527874402, 3372516554], [-36563940449376, -152899886136, 9906827568, 6337079666, 48897345064, -12630760880], [-91029076789023, -167120309180, -17390930338, -30967037771, -32014288745, -21009448679], [74057697526650, -372192414824, -28107979134, -10218581619, 7065406084, 362442521], [-33699761974401, 317295954319, 10392631220, -4446883570, 43346246572, 42083710488], [-54984474798254, 201590060038, 8402049496, -2767697480, 17966897510, 41787338378], [-87096538637250, 395579733671, 15470614993, 23754503874, 23532668073, -29099030812], [-34096155445204, 357448014245, -5309901755, -15569904190, -56593118741, 33364737445], [-58321025303043, 220309575320, 15248968786, 1031820692, -8538078719, -50782630889], [3218897382548, -779560649834, -12880350864, 4290397326, -21254078014, -30397156140], [138849912876274, 479282711918, -4174089590, -1357372848, -24451481970, 9302985037], [-73259492888992, 364497337023, -22928125612, -6818025674, 43364532217, 24210199457], [-98029442517902, 271640292104, -43187228314, -13361087287, 41085775432, -11747742415], [-73736447145707, 85420336696, -33724445838, -9178586549, -1459503905, 18401265869], [-16360696888653, 795895802559, 11052770152, 30471089342, 24390676496, -3883576628], [-36399923966151, 735724765880, 7217298242, 20657992572, 87952244893, -3627951581], [-27605353038542, -39966874446, -11272535976, 23602211663, 62646092438, -48697179424], [97871245284262, 865605294440, -20320728882, -12235775711, -24044593696, -22472136295], [-94847617860074, 460593180241, 6166527673, 28260939652, -42623169823, -31782122071], [51237221028908, 165800733674, 39798666670, 28588003529, 10546768338, -1196615280], [57575866304328, 293182206214, -27429846836, -17511149774, -30736175370, 17671571152], [-146626808238800, 490718671001, 14461262200, -21493498956, -72290570913, 51171847183], [79346645358761, 1012883251440, 53065983946, 28246367412, -10813648887, -4148798275], [-159372962637902, 57157161452, -7362141972, -12448466898, -40306238480, 30087545854], [134601112817906, 627817236617, 38765418455, 31896594486, 122214703211, 1380367694], [-57734326671644, 1471546017234, 16595040232, 30292769157, 70276306338, -14364270392], [-17290679213836, 905914495860, 24097980036, 14171362750, -39453015932, -35517145998], [-1226396060992, 36662704317, 42199943800, 39229690566, 30470440091, -6158680637], [42932546946170, 234326776051, 53692896105, 41962977522, 67324801235, 6492394723], [-94136295375960, 518058990024, -2006255140, -32231415053, -60409715844, -17329127180], [137901951789566, -480759893984, 28662648990, 75225366570, 81923962524, 10201379381], [45973985336140, -101165010124, 28087936424, 14530028920, -8219190902, 62059314752], [-30602786347666, 22998374732, -24860736316, -50134453992, 5446519746, 27107386078], [-63621717602180, -82422348860, -39118648892, -48099149172, -54859473234, -7621234378], [82600486662094, -283333955723, -49487670060, -31559515233, 21366274431, -4977585498], [-133181603962750, 928499356719, 8323186155, -24783365666, 13564518895, 38233858231], [-124932297835842, 1126515727594, 2456718928, 4675550676, 55666686550, -31715171978], [-79432894887684, -179656406419, 16727556592, 13655218692, -41244251189, 48199904847], [16849299269816, 923065634508, 22761136433, 5480211398, 78090803174, 111208126055], [-63782652487950, 862399911131, -18290440845, -32707023702, 15159133365, 21883333038], [211380206910210, -1022368433376, 10342927790, -4215503456, -71835986080, -13609943311], [-164437402741538, 297895339834, 26426267300, 41717405690, -72671427824, 2645695342], [-72740828860750, -19359153837, 61948664568, 48964173246, -117944071519, 5452653433], [-62576801427904, 190775796216, -9800842795, -45630924728, -65456314366, -44063023497], [1839325751730, -1371659498488, 14833986880, -34926538925, -112495091800, -5754736507], [-72739706172692, 545663275449, -46449131614, 24032349919, -112719309081, -84696346865], [-42354679946225, -1605620387062, 4763729556, 9608013659, -4485955761, 68161979983], [143044023355732, -222764946436, -54745328948, 53859130808, -66866008290, -52298554914], [-165611293482586, -998381298692, 11737512056, -46532180350, 24431549394, -50866378754], [268435670070014, 83625860614, 14337122434, -5276717900, -31907180714, 87679230147], [1936551215662, 1213615617769, -43321067768, -24849147127, -74058985109, -106768189387], [-89360176436554, -1053126841690, 47879394532, 78082955731, -19158213868, -92322885644], [152740312765310, 86799741347, -14669649891, -10381537534, -218978577227, -32181807004], [-125459316432544, -297168104888, 12382444648, 10785878250, 100040450552, -18583371378], [-51068314790178, 520262786602, -105350327968, 10711463693, 80747608622, -53894148711], [-399714521844307, 350628158804, 19195451862, 21125758672, -117027293903, 50517042585], [32429308744356, 923101101790, 82241597384, 19513824792, -160306188450, -36623371142], [-23105513985062, 1417239794308, -4311265796, 47027467796, -50813909216, 63946257322], [-226908605616549, 600552221218, 54717367232, 49141453378, 139158915465, -53566962942], [44221793576112, 1637150457329, -18992915112, -17444134690, 139717568383, 15503241115], [138897841968473, -2161751694424, -5565058662, 86962021682, -52861720483, -119860376425], [-82700433573546, 3616530700051, 45081548941, -4027158247, 7546681469, 20741807542], [-168194058475820, -1165538671078, -30510254500, -9157866288, 84083079550, -56122675060], [-81917447605914, 793327249001, -60005979104, -16513338128, -66908611341, -113213997693], [-49395903231785, -1727430167455, 36331690812, -49910884596, 85207460906, -53003791006], [59248358624332, 2971317837441, 96073105045, 27008133704, 61304995007, 22126088709], [189138530913012, -1874032530076, -82704884380, -61349505797, 94554070080, 6108833186], [103235677723750, -467198112624, -44174060794, -58898059072, 74028805044, -107843429559], [243764723120796, 881483601900, -9245986786, -7252820352, -107573146100, 24385333926], [582913141882642, -587847230452, -20101176188, 41960707156, 108175499208, -100459933970], [220709913298423, 2002095661442, -83593745524, -137715136883, 108072954883, 39534013173], [207099496726249, 2819495645481, -83953870224, -65611604166, -24070286980, -13718009100], [501690215511382, -803116256252, -20014312740, 17108260624, -148324751888, -60562655599], [90166409640116, -2632805117021, 29562942806, -97098262809, -283366325467, 78193475169], [837927147878, 1353599179544, 77456575058, -15881060470, 230513550380, 103109182909], [350487250127510, 1424811015641, -76436917200, -1316367405, 130195323659, -73479419011], [-300161598964256, 2667851186510, -63403907502, -36378072602, 13060504698, -42268143070], [-242115252808696, 2333997673150, 115768745385, -11241934794, -169043236332, 35574156809], [39873816132736, -2304068949427, -127300753264, -81515641856, -173679488093, -82606366621], [-230732713563145, 4036453785687, -21084160448, -22835946220, 62392945028, 84142229240], [-378230961588730, 2771186518061, 171885197549, -10738905858, -16898619285, 2058250594], [797918867854250, -2134265267612, -26629883596, 77735218751, 140208249632, -67671009123], [-145465627400282, 1508481175849, -52808461425, -140604770553, -152622326253, -43731559874], [-186735244489180, 1455595186850, 47554747912, 170471104388, 163926123474, -136628783782], [-200063684463918, 587239828719, -164022471831, -61754111498, -337470409, 41265287219], [-19649565059600, 2968127111178, -62159803982, -80696348929, -166551640406, 119037917466], [-199260597257460, -2335180287646, 111510357588, 73747850967, 20419703598, -5603024114], [116861829845588, 857550306915, -107851210720, 20583161688, -219551444245, 25758891383], [161747983796192, -2944148925708, 58912779376, 7495427590, 34186670844, 185822454458], [421665650722998, 1538597482842, -109061238384, -167581836137, 38268418674, 198378904049], [-769921418144488, 473602397064, -20863080328, -41982561538, 40389437352, 121769264804], [401992374132677, 4237386427500, -68898453432, -26388028899, -19431948065, -17369201595], [224854135660406, -2268589982528, -91101868652, -149286407312, 85292024584, -102759024162], [570157190128676, 1654045817270, -26734865976, -47382714244, -305565567730, -150035514346], [-333155608950704, 4001165750860, 216648798724, 32365042889, -88733236704, -45169381044], [156955394150544, -2032344614324, -12743332936, -176580241853, 172472939178, 106379962870], [307145076051696, -2043217687593, 115372241408, 159188990896, 38187029865, 140699784549], [278222348556934, 5576086197005, 70108067415, 175733930161, 2360422579, 51422398948], [-354813737084994, -6529777170685, 61894462885, -110220777110, 12757606305, 20153149442], [415537747159229, 310778749192, -137018965646, 39406073431, 438049448407, -208056262201], [-34492084129152, -3341220496059, -1750670512, 187487308462, 178587627091, 105932742827], [330108499091632, -1592052142970, -60728635330, -121561002221, -82433886538, 7485026282], [516332052011002, -1403039314767, 118112666884, -65337691342, -116232532809, -248615295], [-548166658310898, 1795170929788, -29123641480, 131695058149, 138727549454, -265233534358], [823898058499966, -1247844524058, 49212860826, 205734374831, 85978540874, -16864578325], [-13132140034542, -228972985786, 220356650068, 39569292710, 110785172122, 195088035060], [16871039991138, -2810491118037, 54846736605, 21756985658, 385400872935, 25756481193], [-1560135428859064, 192463532173, -31201682240, 15114081848, 12751411903, -9199692297], [335259687076860, -484732435852, -92124545842, 139723326780, 488647729210, -233798576799], [-428953281733998, -5322210209248, -81137667180, -2231306336, 51873131096, 185454656981], [-612006994876278, 1722878355524, 91801360004, -34590317914, -42887549096, 121763306706], [540124358096686, 3350861813012, 170377688448, -18512583936, -200193143180, -77393998977], [-227979856989160, -2477483820160, -53064117326, 137108320698, -66400376104, -334926044936], [309692118785149, 2463224529271, -14383194296, -175826269044, -70170387494, 282548676806], [-859214387900360, -7160548170448, -135109872508, -141456335408, -17915206600, -44058860268], [-75579815372725, -7697201221733, 60435080628, 39233854316, 133170971700, -197513462904], [-675585276917725, 2598964383880, 123631552436, 261324830441, -7004440227, -269111356949], [-693696269947178, -5373278907266, 11597270688, 54934064819, 565467960850, 83644011605], [-1031335663967260, -2132257264396, -111703594596, -128809110859, -157289389686, 44996703616], [-799360435322067, -3109024243066, 78378536526, 36429827792, 47552092883, -19936173315], [-647351718174606, 2615615271870, -139855162116, 25991605195, 71127975006, -87037068709], [497538902878846, -3659215146484, -122448419896, -321441423825, -227285018684, 90449959573], [-280859242274578, 960883842781, 49263853600, -86723006265, -295139383137, 215500044125], [-580646399025034, -2005559556675, 269343616955, 251775446287, -46671062653, -123325752568], [312066538346666, -4396166506248, -157469034480, -228366227990, -494984006392, 48886983257], [-746585335589960, -6728356969902, 89127389904, -43143391742, -366760943002, 110731861922], [-276402994719422, -2823263674639, -190938728520, -19736563800, 779392828107, -144938999993], [-564811169135340, -4053424628582, 118539008792, 200983340613, 305372401338, -421209290616], [318410815095976, 4546169648582, -106441565670, -261223413429, 542754263182, 126038442978], [51906753509456, -5984392562374, -47303246301, -29256616998, 526143062264, 191633725445], [-937155389259484, -1470662257771, -65635626162, -2956894076, 241273253935, -236593198933], [-62715039399004, -5696557475564, 12359418804, 97200547181, 19684313328, -215375822882], [44118215414743, -4211314950558, 209575607944, 39845141909, 127769698611, -58027006291], [-495032312757875, 2954642714290, -218826146866, -386716260758, -507364116213, -164175057009], [-214787116339697, -4621425981358, -123173651288, -181428827431, 370693895235, 70238899541], [365703900238990, 7190002909398, 2700398084, -49221980425, 59598830266, -183959282523], [-65181688133700, -1178261435734, 106319760876, -160312995810, 511153388062, 240543026468], [519369303709572, -6070423593771, -294402569026, 75121067835, -300812351701, -417873510425], [261160460154268, -5397208236508, 42979616716, -155434789539, -280076020528, 198092997522], [-710432614977260, -560989955104, -3778003582, -429844391781, -53864355486, 36171880861], [169788790721554, 9446992955604, -20510485814, 160180522738, 593874850768, -259921949553], [631533904263402, -4754652924120, -70886863732, 272977470576, 236171592572, 190474972874], [182330040154160, -4526696983276, -241751503458, -87958592096, -533106178666, 58674672177], [-754013069164726, -5802401542373, 64449054411, 259412281166, -478059606697, -163199213483], [-1273088897383896, 478016119321, 131987251664, 287059514210, -30817909973, 16319990027], [-81299903368550, 344345521914, -204909796630, 164911349908, -222262316422, -281953332047], [43368152199760, 491771836796, -16902424437, 128458057936, -265820824458, 324070210611], [64347928996670, -581805937544, 316182647286, -225065288964, 470084790492, 277205695625], [-1188863876917417, 6522939377018, -312176721688, -310165829380, 24955370857, 121900949080], [-235537694942714, -9077987850629, 109775732995, 228633624320, -187684493541, -55478418547], [277093241019784, -3326995807853, -124102964292, -143074554821, -876158945079, -19267804675], [153212949761562, 10941660533992, 374216799396, 183871659086, 807044516418, 397543087930], [418131932244661, 3902001930394, -47565486636, 201201375523, -225037359983, 61843919129], [303958491715340, 14127667499888, 107908488732, 113778001948, -108829952320, -168522320462], [885008359148302, 1244028316132, -216354674066, -280551136177, -856901620276, 174335982657], [-890613144481832, 11338277008629, 154787636992, 172701492184, -605699808517, -497368713901], [1590548875620520, 8771598129609, -149515435087, -200106167168, 278067231275, -310689168015], [-909407110139354, 7186569153377, 71006790991, 153032847458, 10808937175, -130915095334], [1134051406703174, -1264333936498, 237348521008, -115355951904, 204096485598, -326340843010], [-148158731705986, 1846850232143, -528369022429, -3940829974, -309800706531, -591156231618], [1190477701539920, 6308255824351, 193916264496, -34838882720, 320218139247, 360278011451], [674831868191606, 5826752839288, -279377249788, -427392733939, -442954385096, 552632408805], [966639044013854, 2909149970040, 179254840076, 319277405054, 336509975054, 160554112562], [1182619546542512, 1885154378906, -582486252238, -152070869954, -297833655354, -105984291578], [45783302530900, -4690405763477, 360276537926, 390563120861, 858655454613, -678286685131], [669270344023397, -5721613436920, -16989567526, -106300861816, -191052541535, 283623132579], [-1816773458151830, 5327547168217, -107586002825, 7972292361, 197256118643, 5527043452], [340397727020096, -4132749021132, -550404181607, -372765391382, 659601009670, -148691192041], [1469102561575424, 1163238837940, -101724685508, 212725517976, -783585573488, -186495743862], [-300097382076669, 4123843340582, -460235762174, 159792078270, -226449238143, -1051575825309], [678981616147047, 3484424979522, -239982082112, 679832236218, 115550910657, -174747768490], [360985862897736, -5033947554554, -38339420637, 445583525566, 506412484124, -572553796651], [-263018308367318, -5080419500283, 220085229937, -213019091150, 706321375653, 395101515519], [-585689341216256, 242495242439, -462684260000, -544356105670, -13900391307, 82508036545], [1118562442032892, 11631488036409, -219693842131, -44777957210, 949074998327, -335315803551], [-9125738059600, -12376636655452, -115169163608, -380780338290, -807482159108, 511419144636], [1194184736438128, 1445071926850, 490411855684, 217425595205, -277564494590, -397277400038], [-981182854831110, -3968045434098, -248059203804, -503823817087, 345416004850, 332609027542], [-1583883510343682, 6997537407703, 423471907815, 360397483018, 163137239895, -239611342931], [-379966107269510, -12158321179546, -175552125208, 224751278356, 255066128762, 487035920278], [67858447982680, -4747511552279, -549049637452, -17201497579, -1130459363903, -903935036643], [993527791339468, 7306198309210, 72274934238, -236719429866, 386167855358, 147646421576], [-1353628041202454, -1382213150912, 81142604864, -596807089671, -118911048154, 255717686858], [-569597402243010, -9821454104623, 687790450889, -119250260644, -770121087465, 761780022958], [1796380870773112, -13650829421609, -67157705776, -487480488344, 165566511519, 625876284671], [-450428316756592, 6333062941142, 300239842068, 362924546594, -613572258950, 632219576506], [924795583211898, -23182782815650, -203239743036, 8463049367, -663952851338, -346733024061], [982844816878141, -4108641550046, -109050250684, -636207119870, -85094210169, -461915402724], [262370148611464, -6597416558399, -460339609680, 139482941240, 404129316363, 347861393131], [1639036897822544, 2510204757001, 35777358880, 99146087938, 474425872423, -340039065417], [1126730650010998, -14736370281973, -145239452755, -224610708524, 307067981041, -530104926730], [-852602507164746, -2573733668062, -619234126866, 270823395617, 568657433758, 191070190547], [482633084831634, 3795975499762, -102862466768, -994637231731, -368332982760, 171814276066], [-919598366714512, -2906998085472, -165454364252, 551613547750, -914992847664, -152726962680], [2610410962835788, 8488178458094, 116460552126, -225594743005, -370724104946, -669568358928], [1160583598461976, -21024739816909, 260292445624, 417986319052, 366753312459, 379257213387], [1578068801468706, 7670966757609, -115561202529, -339728662573, -1519459818277, 654411567312], [-1104209737789084, 1347562675454, 185554081836, -241376518022, 800250865610, 381410643900], [3052214761307106, 213662147056, 40563147016, 938189568917, 274480841848, -96769311363], [2281619998695389, -11555063240156, -254403313742, -456542235800, -351999140147, 826223539199], [368659587290731, -9237723565360, -364878857548, -287952801073, -558368115499, -212863772101], [-1099513129826706, -3947993997307, 2640466032, 587488963995, -754695742737, -52121854198], [-1838029866496852, -2816886333328, 116699351208, 812813934064, 1098244321236, 229367625404], [-1056753689993232, 5204613331791, -309610596832, 123739897256, -91886175895, 245474295605], [1125105998632162, 9413167376287, 152113297623, -653217110124, 180732751653, -479611536856], [2229286264157048, 12603383610728, -310277760961, -303514848406, -396363971690, 2340691445], [-2260699050068778, 3540854722254, -492408358720, -616543815056, -555026531672, -569290023432], [2118545266351470, -10125652980412, 261533832620, 508939113738, -225740020820, 400823089186], [676680327947684, -13561302655931, -335179158462, -78998538779, -983190085533, -415127765197], [1198245243408356, -2704820567942, -557640930748, -540822014015, -898262448302, -290706971608]]
